# Copyright (c) 2005-2010 oc2pus
# Copyright (c) 2011 Evstifeev Roman <someuniquename@gmail.com>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
# Please submit bugfixes or comments via http://bugs.opensuse.org/

# vim: set ts=4 sw=4 et:
 
Name:           sonic-visualiser
Summary:        A program for viewing and analysing contents of audio files
Version:        1.9
Release:        6.1
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://www.sonicvisualiser.org/
Source:         %{name}-%{version}.tar.bz2
Patch:          sonic-visualiser-ld-X11-fix.patch
#PATCH-FIX-UPSTREAM gcc-4.7.patch avvissu@yandex.ru -- Patch to fix build with gcc 4.7
Patch0:         gcc-4.7.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-build
BuildRequires:  curl-devel
BuildRequires:  dssi
BuildRequires:  gcc-c++
BuildRequires:  fftw3-devel
BuildRequires:  freetype2-devel
BuildRequires:  ladspa
BuildRequires:  libbz2-devel
BuildRequires:  libid3tag-devel
BuildRequires:  alsa-devel
BuildRequires:  libjack-devel
BuildRequires:  liblo-devel
BuildRequires:  liblrdf-devel
BuildRequires:  libmad-devel
BuildRequires:  flac
BuildRequires:  flac-devel
BuildRequires:  libogg-devel
BuildRequires:  liboggz-devel >= 0.9.5
BuildRequires:  libpng-devel
# BuildRequires:  libfishsound-devel >= 0.8.0
BuildRequires:  libpulse-devel
BuildRequires:  libraptor-devel >= 2.0.4
BuildRequires:  librasqal-devel
BuildRequires:  libredland-devel >= 1.0.14
BuildRequires:  librubberband-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libspeex-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libxslt-devel
BuildRequires:  portaudio-devel
BuildRequires:  qt-devel >= 4.2
BuildRequires:  zlib-devel
BuildRequires:  update-desktop-files
BuildRequires:  vamp-plugin-sdk-devel
BuildRequires:  xorg-x11-devel
Requires:       dssi
Requires:       ladspa
 
%description
Sonic Visualiser is a program for viewing and analysing the contents
of music audio files.
 
With Sonic Visualiser you can:
* Load audio files in various formats and view their waveforms
 
* Look at audio visualisations such as spectrogram views, with
  interactive adjustment of display parameters
 
* Annotate audio data by adding labelled time points and defining
  segments, point values and curves
 
* Run feature-extraction plugins to calculate annotations
  automatically, using algorithms such as beat trackers, pitch
  detectors and so on
 
* Import annotation data from various text formats and MIDI files
 
* Play back the original audio with synthesised annotations, taking
  care to synchronise playback with the display position
 
* Slow down playback and loop segments of interest, including
  seamless looping of complex non-contiguous areas
 
* Export annotations and audio selections to external files.
 
* Sonic Visualiser can also be controlled remotely using the Open Sound
  Control (OSC) protocol

%package mad
Summary:        MP3 Support for %{name}
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name} = %{version}-%{release}

%description mad
This package is empty but ensures you get a %{name} package
with MP3 support through libmad.
 
%prep
%setup -q -n %{name}-%{version}
%patch -p1
%patch0 -p1

 
%build
CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" \
%configure
# don't pass -j flags, breaks build
%__make
 
%install

%__install -dm 755 %{buildroot}%{_bindir}
%__install -m 755 sonic-visualiser/%{name} \
    %{buildroot}%{_bindir}
 
# plugin dir
%__install -dm 755 %{buildroot}%{_libdir}/vamp
 
# icon
%__install -dm 755 %{buildroot}%{_datadir}/pixmaps
%__install -m 644 sonic-visualiser/icons/svicon32.png \
    %{buildroot}%{_datadir}/pixmaps/%{name}.png
  
# Menu
%__cat > sonic-visualiser/%{name}.desktop << EOF
[Desktop Entry]
Name=%{name}
GenericName=%{name}
Comment=A program for viewing and analysing contents of audio files
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
MimeType=application/x-sonicvisualiser;application/x-sonicvisualiser-layer;application/x-ogg;audio/x-flac;audio/x-mp3;audio/x-wav;audio/wav;application/ogg;audio/x-vorbis+ogg;
EOF
%suse_update_desktop_file -i %{name} Audio AudioVideo Music

cat<<EOF >README.MP3
This package provides %{name} with MP3 support through libmad.
EOF
 
%clean
%{?buildroot:%__rm -rf "%{buildroot}"}
 
%files
%defattr(-,root,root)
%doc sonic-visualiser/COPYING sonic-visualiser/README*
%{_bindir}/%{name}
%dir %{_libdir}/vamp
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop

%files mad
%defattr(-,root,root)
%doc README.MP3
 
%changelog
* Mon Oct  6 2014 avvissu@yandex.ru
- Patch to fix build (gcc-4.7.patch)
* Wed Mar 14 2012 pascal.bleser@opensuse.org
- add bits to enable mp3 support with mad when built on Packman
* Wed Mar 14 2012 pascal.bleser@opensuse.org
- remove dependency on licenses, gone in 12.1
- reformat spec file, fix license tag to be compliant with SPDX
* Thu Oct 20 2011 someuniquename@gmail.com
- update to 1.9
* Wed May  5 2010 toni@links2linux.de
- update to 1.7.2
* Thu Oct 29 2009 toni@links2linux.de
- update to 1.7.1
- This release contains a small number of enhancements and bug fixes.
  For more information, please read the change log at:
  https://sourceforge.net/projects/sv1/files/sonic-visualiser/1.7.1/CHANGELOG/download
* Mon Oct 26 2009 toni@links2linux.de
- update to 1.7
- The main focus of this release is to improve editing of note and region layers.
  It can import MIDI files that use SMPTE timecode for event timing, and
  optionally display time in seconds and frames at various frame rates throughout.
  A crash on exit in Windows has been fixed, and a number of other bugfixes are
  included.
* Mon Mar 16 2009 toni@links2linux.de
- update to 1.5
* Thu Dec 11 2008 toni@links2linux.de
- update to 1.4
* Thu Jul 10 2008 toni@links2linux.de
- update to 1.3
- using new rubberband-1.2
- added PulseAudio output driver
* Sun Mar 23 2008 toni@links2linux.de
- rebuild with new vamp-plugin-sdk
* Wed Feb 20 2008 toni@links2linux.de
- update to 1.2
* Mon Dec 31 2007 toni@links2linux.de
- rebuild with new libraptor/vamp-sdk packages
* Sun Sep  9 2007 toni@links2linux.de
- openSUSE-10.3 build corrected BuildRequires
* Tue Jun  5 2007 toni@links2linux.de
- rebuild with libfishsound1 (0.8.0)
* Fri May 11 2007 toni@links2linux.de
- update to 1.0
* Tue Mar 20 2007 toni@links2linux.de
- update to 1.0pre3
- moved all vamp-plugins to seperate packages
- using vamp-plugin-sdk to build
- switched to portaudio-19
* Mon Jan  1 2007 toni@links2linux.de
- build SuSE-10.2, corrected BuildRequires
* Thu Sep 21 2006 toni@links2linux.de
- build for packman
* Sat May 27 2006 oc2pus@arcor.de 0.9-0.oc2pus.2
- rebuild for SuSE-10.1 (no dssi-devel)
* Sun May 21 2006 oc2pus@arcor.de 0.9-0.oc2pus.1
- Initial release 0.9
- added vamp-QM-plugin 1.0
- added vamp-aubio-plugin 0.3.0
- added vamp-mazurka-plugins
  download sources from http://sv.mazurka.org.uk and packaged as tar.bz2,
  added libmain.cpp and create a shared lib with allmazurka-plugins
